version 9.2
global stub ch1_f02
/*
	Research body fat dataset.
	Example to illustrate univariate FP approach.
	Predict percent body fat from BMI and other variables.

	Graphs:
	Smoothed residuals from cubic; smoothed residuals from FP1.
	(Note: N = 327)
*/
set more off
mvmb_load res_bodyfat

* Fit cubic and predict residuals
fracpoly regress pbfm bmi 1 2 3
predict resfc, res

* Fit FP1 and predict residuals
fracpoly regress pbfm bmi -1
predict resffp, res

* Smoothed residuals (cubic)
local x bmi
local y1 resfc
running_ci `y1' `x'
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-10) yu(10)

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter `y1' `x', ytitle("") ms(oh) mcolor(gs10) xlab(10(10)60) xtitle("") ) ///
 `r(cmd3)' , ///
  title("Cubic model") name(g1, replace) nodraw

* Smoothed residuals (FP1)
local y1 resffp
running_ci `y1' `x'
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-10) yu(10)

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter `y1' `x', ytitle("") ms(oh) mcolor(gs10) xlab(10(10)60) xtitle("") ) ///
 `r(cmd3)' , ///
  title("FP1 model") name(g2, replace) nodraw

graph combine g1 g2, sav($stub, replace) nodraw ///
 b2title("bmi (body mass index)") l1title("Residuals and smoothed residuals")

gph2emf $stub
gph2eps $stub

graph drop g1 g2
set more on
