version 9.2
global stub ch1_f05
/*
	GBSG breast cancer data.
	Example to illustrate univariate FP approach.
	Univariate models for age.
*/
set more off
mvmb_load gbsg_br_ca
mvmb_logopen
qui {
	* Model 1: age linear
	local mod 1
	local tit`mod' "age linear"
	foreach v of var age {
		stcox `v'
		predict f`v'_`mod', xb
		meanzero f`v'_`mod', replace
		local dev`v'_`mod'=-2*(e(ll_0)-e(ll))
		local p`v'_`mod'=chi2tail(1,`dev`v'_`mod'')
	}

	* Model 2: age quadratic
	local ++mod
	local tit`mod' "age quadratic"
	foreach v of var age {
		gen `v'q=`v'^2
		stcox `v' `v'q
		predict f`v'_`mod', xb
		meanzero f`v'_`mod', replace
		local dev`v'_`mod'=-2*(e(ll_0)-e(ll))
		local p`v'_`mod'=chi2tail(2,`dev`v'_`mod'')
	}

	* Model 3: age FP1
	local ++mod
	local tit`mod' "age FP1"
	foreach v of var age {
		fracpoly stcox `v', degree(1)
		predict f`v'_`mod', xb
		meanzero f`v'_`mod', replace
		local dev`v'_`mod'=-2*(e(ll_0)-e(ll))
		local p`v'_`mod'=chi2tail(2,`dev`v'_`mod'')
	}

	* Model 4: age FP2
	local ++mod
	local tit`mod' "age FP2"
	foreach v of var age {
		fracpoly stcox `v', degree(2)
		predict f`v'_`mod', xb
		meanzero f`v'_`mod', replace
		local dev`v'_`mod'=-2*(e(ll_0)-e(ll))
		local p`v'_`mod'=chi2tail(4,`dev`v'_`mod'')
	}

	* Model 5: age categoric, cutpts (45, 60)
	local ++mod
	local tit`mod' "age categ (1)"
	local cutage 45 60
	foreach v of var age {
		local df: word count `cut`v''
		categ `v', cutpoint(`cut`v'') gen(temp)
		tab temp, gen(temp)
		drop temp1
		stcox temp*
		predict f`v'_`mod', xb
		meanzero f`v'_`mod', replace
		local dev`v'_`mod'=-2*(e(ll_0)-e(ll))
		local p`v'_`mod'=chi2tail(`df',`dev`v'_`mod'')
		drop temp*
	}

	* Model 6: age categoric, cutpts (40)
	local ++mod
	local tit`mod' "age categ (2)"
	local cutage 40
	foreach v of var age {
		local df: word count `cut`v''
		categ `v', cutpoint(`cut`v'') gen(temp)
		tab temp, gen(temp)
		drop temp1
		stcox temp*
		predict f`v'_`mod', xb
		meanzero f`v'_`mod', replace
		local dev`v'_`mod'=-2*(e(ll_0)-e(ll))
		local p`v'_`mod'=chi2tail(`df',`dev`v'_`mod'')
		drop temp*
	}
	noi di
	forvalues m=1/`mod' {
		noi di as txt %-25s "`tit`m''"  as res %9.3f `devage_`m'' %7.4f `page_`m''
	}	
	
	* Plot functions. Using color gs8 for line 6; s1mono default is gs14, much too pale.
	clp
	local v age
	local fs
	forvalues m=1/`mod' {
		local fs `fs' f`v'_`m'
	}
	line `fs' `v' if `v'>=25 & `v'<=75, sort clp($clp) ///
	 ytitle("Log relative hazard") xtitle("Age, years") c(l l l l J J) ///
	 legend(label(1 "Linear") label(2 "Quadratic") label(3 "FP1") ///
	 label(4 "FP2") label(5 "Cut(45, 60)") label(6 "Cut(40)") ring(0) pos(1) col(1)) ///
	 lcolor(. . . . . gs8) sav($stub, replace) nodraw
}
log close

gph2emf $stub
gph2eps $stub

set more on
