version 9.2
global stub ch6_f01
/*
	Prostate data.
	Smoothed residuals from full linear and MFP(.05)
	against cavol and weight2.
*/
set more off
mvmb_load prostate_ca
mvmb_logopen

* vars in order of stat significance in full linear model
global vars cavol svi pgg45 weight bph cp age

* Model 1. Full linear
regress lpsa $vars
predict full, res

* Model 2. MFP(.05)
gen lcavol = ln(cavol)
regress lpsa lcavol weight svi
predict mfp, res

local xla1 xla(0(10)30)
local xla2 xla(0(40)120)

* panel 1
local x cavol
local y full 
running_ci `y' `x'

residual_plot_cmd s_`x' ll_`x' ul_`x' `x' if `x'<33, yl(-2) yu(2)

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter `y' `x' if `x'<33, ytitle("Residuals (full)") ms(oh) mcolor(gs12) `xla1' xtitle("") ) ///
 `r(cmd3)' , name(g1, replace) nodraw

* panel 2
local x weight
local y full 
running_ci `y' `x'

residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-2) yu(2)

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter `y' `x', ytitle("") ms(oh) mcolor(gs12) `xla2' xtitle("") ) ///
 `r(cmd3)' , name(g2, replace) nodraw

* panel 3
local x cavol
local y mfp 
running_ci `y' `x'

residual_plot_cmd s_`x' ll_`x' ul_`x' `x' if `x'<33, yl(-2) yu(2)

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter `y' `x' if `x'<33, ytitle("Residuals (MFP)") ms(oh) mcolor(gs12) `xla1' xtitle("`x'") ) ///
 `r(cmd3)' , name(g3, replace) nodraw

* panel 4
local x weight
local y mfp 
running_ci `y' `x'

residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-2) yu(2)

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter `y' `x', ytitle("") ms(oh) mcolor(gs12) `xla2' xtitle("`x'") ) ///
 `r(cmd3)' , name(g4, replace) nodraw

graph combine g1 g2 g3 g4, sav($stub, replace) nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3 g4
set more on
