version 9.2
global stub ch6_f17
/*
	Diabetes data.
	Fitted linear and FP1 function plots.
*/
set more off
mvmb_load diabetes

// Model 1: linear
fracpoly regress cpep age 1 base
fracpred f1age, for(age)
fracpred f1base, for(base)

// Model 3: best FP1
fracpoly regress cpep age -1 base 0
predict fit
fracpred f2age, for(age)
fracpred f2base, for(base)
fracpred s2age, for(age) stdp
fracpred s2base, for(base) stdp
* Standardise partial fits to have same mean as cpep
qui sum cpep
local mean = r(mean)
qui sum f2age
qui replace f2age = f2age-r(mean)+`mean'
qui sum f2base
qui replace f2base = f2base-r(mean)+`mean'
gen l2age = f2age-1.96*s2age
gen u2age = f2age+1.96*s2age
gen l2base = f2base-1.96*s2base
gen u2base = f2base+1.96*s2base

tokenize age base
forvalues j=1/2{
	local x ``j''
	twoway ///
	 ( rarea l2`x' u2`x' `x', sort pstyle(ci) ) ///
	 ( line f2`x' f1`x' `x', sort lstyle(refline p2) pstyle(p2) ) ///
	 , xtitle("`x'", size(large)) ytitle(" ", size(large)) legend(off) ///
	 name(g`j', replace) nodraw
}

twoway ///
 ( scatter cpep fit, ms(oh) ) ///
 ( line fit fit, sort lstyle(refline) ) ///
 , xtitle("Fitted values", size(large)) ytitle(" ", size(large)) leg(off) ///
 name(g3, replace) nodraw

graph combine g1 g2 g3, sav($stub, replace) ycommon l1title("cpep") nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3
set more on
