version 9.2
global stub ch6_f18
/*
	Whitehall 1 data.
	MFP model for chd outcome as Cox model.
	Plot fitted partial predictors and CI (save as emf).
*/
set more off
mvmb_load whitehall1

stset pyar chd
rename ht height
rename wt weight

* Fit MFP model
fracpoly stcox age -0.5 cigs 0 chol height weight map gradd1 gradd2 gradd3, nohr

local j 0
local t1 Age, yrs
local t2 Cigarettes/day
local t3 Serum cholesterol, mmol/l
local t4 Height, cm
local t5 Weight, kgs
local t6 Mean arterial pressure, mm Hg
foreach v of var age cigs chol height weight map {
	local ++j
	preserve
	qui bysort `v':drop if _n>1
	fracpred f, for(`v')
	fracpred s, for(`v') stdp
	gen l = f-1.96*s
	gen u = f+1.96*s
	twoway ///
	 (rarea l u `v', pstyle(ci) sort) ///
	 (line f `v', sort lstyle(refline) pstyle(p2)) ///
	 , title("`v'") xtitle("") ytitle("") legend(off) ///
	 name(g`j', replace) nodraw
	restore
}

graph combine g1 g2 g3 g4 g5 g6, sav($stub, replace) ///
 l1title("Log relative hazard") imargin(tiny) nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3 g4 g5 g6
set more on
