version 9.2
global stub ch6_t04
/*
	GBSG breast cancer data.
	Extending linear model using restricted cubic splines with 3 knots.
*/
set more off
mvmb_load gbsg_br_ca
mvmb_logopen

preserve

stcox gradd1 nodes pgr hormon, nohr nolog
local dev0=-2*e(ll)
predict index, xb
meanzero index, replace

global vars nodes pgr age size er

* Harrell (2001) suggestion of knot positions
local centiles 5 50 95
local ncs: word count `centiles'
qui foreach v of var $vars {
	centile `v', c(`centiles')
	local cs
	forval j=1/`ncs'{
		local c`j'=r(c_`j')
		local cs `cs' `c`j''
	}
	splinegen `v' `cs', orthog
	local sv`v' `r(names)'
}

* Extend model with splines for continuous vars already in model
foreach v of var nodes pgr {
	qui stcox `sv`v'', offset(index)
	local df: word count `sv`v''
	local dev=-2*e(ll)
	di "var = `v' dev diff = " `dev0'-`dev' " P (spline terms) = " chi2tail(`df', `dev0'-`dev')
}

* Extend model with splines for continuous vars not in model
foreach v of var age size er {
	qui stcox `sv`v'', offset(index)
	local df: word count `sv`v''
	local dev=-2*e(ll)
	di "var = `v' dev diff = " `dev0'-`dev' " P (spline terms) = " chi2tail(`df', `dev0'-`dev')
}

**********************************************************************
* Repeat for model II
restore

fracgen age -2 -.5, adj(mean)
fracgen nodes -2 -1, adj(mean)
fracgen pgr .5, adj(mean)
stcox age_1 age_2 gradd1 nodes_1 nodes_2 pgr_1 hormon, nohr nolog
local dev0 = -2*e(ll)
predict index, xb
meanzero index, replace

global vars nodes pgr age size er

* Harrell (2001) suggestion of knot positions
local centiles 5 50 95
local ncs: word count `centiles'
qui foreach v of var $vars {
	centile `v', c(`centiles')
	local cs
	forval j=1/`ncs'{
		local c`j' = r(c_`j')
		local cs `cs' `c`j''
	}
	splinegen `v' `cs', orthog
	local sv`v' `r(names)'
}

* Extend model with splines for continuous vars already in model
foreach v of var nodes pgr age {
	qui stcox `sv`v'', offset(index)
	local df: word count `sv`v''
	local dev = -2*e(ll)
	di "var = `v' dev diff = " `dev0'-`dev' " P (spline terms) = " chi2tail(`df', `dev0'-`dev')
}

* Extend model with splines for continuous vars not in model
foreach v of var size er {
	qui stcox `sv`v'', offset(index)
	local df: word count `sv`v''
	local dev=-2*e(ll)
	di "var = `v' dev diff = " `dev0'-`dev' " P (spline terms) = " chi2tail(`df', `dev0'-`dev')
}

log close
set more on
