version 9.2
global stub ch7_f01
/*
	Advanced prostate cancer data.
	FP2 functions and treatment effect for age.
*/
set more off
mvmb_load adv_prostate_ca

global cvars age wt sbp dbp sz ap hg sg
global bvars pf hx bm stage ekg

mfpi stcox $cvars $bvars, select(.05) with(rx) fp2(age) showmodel genf(f) gendiff(d)

* Age: functions
global stuff1 sort clp(l _) clwidth(medthick ..) clcolor(gs6 ..) ///
 xlab(50(10)90) ytitle("Log hazard ratio", size(large)) ///
 legend(pos(11) ring(0) col(1) lab(1 "Placebo") lab(2 "Trt E"))

global stuff2 sort clp(-) clwidth(medthick) clcolor(gs12) ///
 yaxis(2) ytitle("CDF", size(large) axis(2)) ///
 yscale(range(0,2) axis(2)) ylab(0(.5)1, axis(2))

cumul age, gen(agec)
sort age agec

twoway line f1_0 f1_1 age, $stuff1 ///
 || line agec age, $stuff2 xtitle("") leg(lab(3 "CDF(age)")) name(g1,replace) nodraw

* Age: treatment effect
gen ll = d1_1-1.96*d1s_1
gen ul = d1_1+1.96*d1s_1

global stuff1 sort clp(l - -) clwidth(medthick) clstyle(p1 p1 p1) ///
 xlab(50(10)90) ytitle("Log hazard ratio (treatment effect)", size(large)) ///
 xtitle("") legend(off) ///
 yline(-0.178 0, lpattern(-) lwidth(thin) lcolor(gs6))

gen y1 = 0
gen y2 = -0.178

residual_plot_cmd d1_1 ll ul age, nozero noparen

twoway `r(cmd2)' || `r(cmd3)' lwidth(medthick) ///
 || line y1 y2 age, sort clp(- -) lwidth(thin ..) lcolor(gs6 .) ///
 , ytitle("Log hazard ratio (treatment effect)", size(large)) ///
 xlab(50(10)90) xtitle("") legend(off) ///
 name(g2, replace) nodraw

graph combine g1 g2, sav($stub, replace) b2title("Age")

gph2emf $stub
gph2eps $stub

graph drop g1 g2
set more on
