version 9.2
global stub ch7_f11
/*
	Kidney cancer data.
	Bootstraps of STEPP with params (sliding window) 40,60; (tail-oriented) 6.
	The bootstrap was run first, creating files ch7_f11_1.dta and ch7_f11_2.dta.
	Then the code was commented out (see below), leaving only the plots to do.
*/

/* ************************* BEGIN COMMENTED OUT PART **************************
cap prog drop job
prog def job
args fn vn reps tail param1 param2
/*
	When tail = 0 use sliding window, n1=param1, n2=param2.
	When tail = 1 use tail oriented, g=param1.
*/
quietly {
	tempvar w
	* Original data
	if `tail'==0 {
		stepp_window stcox `vn', gen(O) with(trt) n1(`param1') n2(`param2') sort(order)
	}
	else {
		stepp_tail stcox `vn', gen(O) with(trt) g(`param1') sort(order)
	}
	gen int `w' = .		// bootstrap frequency weights
	forval j=1/`reps' {
		bsample, weight(`w')
		streset [fweight=`w']
		if `tail'==0 {
			stepp_window stcox `vn', gen(S) with(trt) n1(`param1') n2(`param2') sort(order)
		}
		else {
			stepp_tail stcox `vn', gen(S) with(trt) g(`param1') sort(order)
		}
		cap drop S`j'
		rename Sb S`j'
		if mod(`j',100)==0 noi di `j', _cont
	}
	drop Smean Sse
	streset [fweight=1]
}
saveold `"`fn'"', replace	// when run in Stata 10, creates Stata 9 format dataset
end

set more off
local stub $stub
mvmb_load kidney_ca
gen int order = _n

set seed 10101

job `stub'_1 wcc 1000 0 40 60
job `stub'_2 wcc 1000 1 6
exit
************************* END COMMENTED OUT PART ************************** */

set more off
local stub $stub
mvmb_load

// Sliding window
use `stub'_1, replace
drop __000000

// Bootstrap mean and CI via bootstrap SE
egen bootmean = rmean(S*)
egen bootsd = rsd(S*)
gen bootll = bootmean-1.96*bootsd
gen bootul = bootmean+1.96*bootsd

twoway ///
 (line S101-S120 Omean, sort clp(l ..) lcolor(gs12 ..) lwidth(thin ..) ) ///
 (line Ob bootmean bootll bootul Omean, sort clp(l _ _ _) ///
  lcolor(gs1 gs1 gs5 gs5) lwidth(medthick ..) ) ///
 , xlab(5(5)15) xtitle(" ") ytitle(" ") legend(order(21 22) ///
 label(21 "Original data") label(22 "Bootstrap mean + 95% CI") ring(0) pos(11) col(1)) ///
 title("Sliding window (SW)")  ylab(-1.5(0.5)1.5) ysca(r(-1.5 1.5)) name(g1, replace) nodraw

// Tail-oriented
use `stub'_2, replace
sort pid
drop __000000

// Bootstrap mean and CI via bootstrap SE
egen bootmean = rmean(S*)
egen bootsd = rsd(S*)
gen bootll = bootmean-1.96*bootsd
gen bootul = bootmean+1.96*bootsd

// Add results from bootstrap analysis of MFPI. First free up some memory.
drop S1-S100 S121-S1000
merge pid using mfpicurves
egen mean = rmean(d*)
egen sd = rsd(d*)
gen low = mean-1.96*sd
gen high = mean+1.96*sd

sum Omean
local olow = r(min)-.01
local ohigh = r(max)+.01
replace wcc = . if wcc<`olow' | wcc>`ohigh'

twoway ///
 (line S101-S120 Omean, sort clp(l ..) lcolor(gs12 ..) lwidth(thin ..) ) ///
 (line Ob bootmean bootll bootul Omean, sort clp(l _ _ _) ///
  lcolor(gs1 gs1 gs5 gs5) lwidth(medthick ..) ) ///
 (line low high wcc if wcc>`olow' & wcc<`ohigh', ///
 sort clp(- -) lcolor(gs3 gs3) lwidth(medthick ..) ) ///
 , xlab(5(5)15) xtitle(" ") ytitle(" ") ///
  leg(order(21 22 25) label(21 "Original data") label(22 "Bootstrap mean + 95% CI") ///
  label(25 "Bootstrap MFPI + 95% CI") ring(0) pos(11) col(1)) ylab(-1.5(0.5)1.5) ysca(r(-1.5 1.5)) ///
  title("Tail-oriented (TO)") name(g2, replace) nodraw

graph combine g1 g2, sav($stub, replace) nodraw ///
 b2title("White cell count") l1title(Beta estimators) ycommon

gph2emf $stub
gph2eps $stub

graph drop g1 g2
set more on
